Index: kernel/generic/include/ddi/irq.h
===================================================================
--- kernel/generic/include/ddi/irq.h	(revision 78ffb70588017cf4018251b150c250f7ac4b52bd)
+++ kernel/generic/include/ddi/irq.h	(revision f40131243ad1635ce6cd59eaf5a91902710c0306)
@@ -54,4 +54,5 @@
 	/** Read 4 bytes from the I/O space. */
 	CMD_PIO_READ_32,
+	
 	/** Write 1 byte to the I/O space. */
 	CMD_PIO_WRITE_8,
@@ -62,12 +63,29 @@
 	
 	/**
-	 * Perform a bit test on the source argument and store the result into
-	 * the destination argument.
+	 * Write 1 byte from the source argument
+	 * to the I/O space.
+	 */
+	CMD_PIO_WRITE_A_8,
+	/**
+	 * Write 2 bytes from the source argument
+	 * to the I/O space.
+	 */
+	CMD_PIO_WRITE_A_16,
+	/**
+	 * Write 4 bytes from the source argument
+	 * to the I/O space.
+	 */
+	CMD_PIO_WRITE_A_32,
+	
+	/**
+	 * Perform a bit masking on the source argument
+	 * and store the result into the destination argument.
 	 */
 	CMD_BTEST,
 	
 	/**
-	 * Predicate the execution of the following N commands by the boolean
-	 * value of the source argument.
+	 * Predicate the execution of the following
+	 * N commands by the boolean value of the source
+	 * argument.
 	 */
 	CMD_PREDICATE,
@@ -75,4 +93,5 @@
 	/** Accept the interrupt. */
 	CMD_ACCEPT,
+	
 	/** Decline the interrupt. */
 	CMD_DECLINE,
